@@ -5,28 +5,24 @@ Argument parser for Otter command-line tools
 import sys
 import argparse
 
+from textwrap import dedent
+
 INVOKED_FROM_PYTHON = "__main__.py" in sys.argv[0]
 PROG = ("otter", "python3 -m otter")[INVOKED_FROM_PYTHON]
 
-# from . import assign
-# from . import check
-# from . import export
-# from . import generate
-# from . import grade
-# from . import service
-
 def get_parser():
-    """Creates and returns the argument parser for Otter
-    
+    """
+    Creates and returns the argument parser for Otter
+
     Returns:
         ``argparse.ArgumentParser``: the argument parser for Otter command-line tools
     """
 
-    parser = argparse.ArgumentParser(prog=PROG, description="""
-    A Python-based autograder for Jupyter Notebooks and Python scripts that runs locally on the instructors machine.
-    Also supports use of Gradescope's autograding service, assignment distribution with otter-assign, and public tests
-    that students can run while working on assignments.
-    """)
+    parser = argparse.ArgumentParser(prog=PROG, description=dedent("""\
+    Command-line utility for Otter-Grader, a Python-based autograder for Jupyter Notebooks, RMarkdown 
+    files, and Python and R scripts that runs locally on the instructors machine. For more information,
+    see https://otter-grader.readthedocs.io/
+    """))
     parser.add_argument("--version", default=False, action="store_true", help="Show version information and exit")
     subparsers = parser.add_subparsers()
 
@@ -35,30 +31,12 @@ def get_parser():
     assign_parser = subparsers.add_parser("assign", description="Create distribution versions of otter-assign-formatted notebook")
     assign_parser.add_argument("master", help="Notebook with solutions and tests.")
     assign_parser.add_argument("result", help="Directory containing the result.")
-    assign_parser.add_argument("-l", "--lang", default=None, choices=["python", "r"], nargs="?", help="Assignment programming language; defaults to Python")
-    assign_parser.add_argument("--no-export-cell", help="Don't inject an export cell into the notebook", default=False, action="store_true")
     assign_parser.add_argument("--no-run-tests", help="Don't run tests.", default=False, action="store_true")
-    assign_parser.add_argument("--no-init-cell", help="Don't automatically generate an Otter init cell", default=False, action="store_true")
-    assign_parser.add_argument("--no-check-all", help="Don't automatically add a check_all cell", default=False, action="store_true")
     assign_parser.add_argument("--no-pdfs", help="Don't generate PDFs; overrides assignment config", default=False, action="store_true")
-    # assign_parser.add_argument("--no-filter", help="Don't filter the PDF.", default=False, action="store_true")
-    # assign_parser.add_argument("--instructions", help="Additional submission instructions for students")
-    # assign_parser.add_argument("--jassign", default=False, action="store_true", help="Use jassign output notebook format")
+    assign_parser.add_argument("--username", default=None, help="Gradescope username for generating a token")
+    assign_parser.add_argument("--password", default=None, help="Gradescope password for generating a token")
     assign_parser.add_argument("--debug", default=False, action="store_true", help="Do not ignore errors in running tests for debugging")
 
-    # generate options -- COMMENTED OUT BECAUSE YOU SHOULD USE THE ASSIGNMENT METADATA FOR THIS
-    # assign_parser.add_argument("--generate", default=False, action="store_true", help="Generate Gradescope autograder zipfile")
-    assign_parser.add_argument("-r", "--requirements", nargs='?', default=None, help="Path to requirements.txt file; ignored if no generate key in assignment metadata")
-    assign_parser.add_argument("--overwrite-requirements", default=False, action="store_true", help="Overwrite (rather than append to) default requirements for Gradescope; ignored if no REQUIREMENTS argument")
-    # assign_parser.add_argument("--threshold", type=float, default=None, help="Pass/fail score threshold; use with --generate only")
-    # assign_parser.add_argument("--points", type=float, default=None, help="Points possible, overrides sum of test points; use with --generate only")
-    # assign_parser.add_argument("--seed", type=int, default=None, help="A random seed to be executed before each cell; use with --generate only")
-    # assign_parser.add_argument("--show-stdout", action="store_true", default=False, help="Show autograder test results (P/F only, no hints) after publishing grades (incl. hidden tests)")
-    # assign_parser.add_argument("--show-hidden", action="store_true", default=False, help="Show autograder results for hidden tests after publishing grades")
-    # assign_parser.add_argument("--grade-from-log", default=False, action="store_true", help="Whether to grade assignments based on the logged environments")
-
-    assign_parser.add_argument("files", nargs='*', help="Other support files needed for distribution (e.g. .py files, data files)")
-
     assign_parser.set_defaults(func_str="assign.main")
 
 
@@ -87,39 +65,18 @@ def get_parser():
 
     ##### PARSER FOR otter generate #####
     generate_parser = subparsers.add_parser("generate", description="Generates zipfile to configure Gradescope autograder")
-    generate_subparsers = generate_parser.add_subparsers()
+    generate_parser.add_argument("-t", "--tests-path", nargs='?', type=str, default="./tests/", help="Path to test files")
+    generate_parser.add_argument("-o", "--output-path", nargs='?', type=str, default="./", help="Path to which to write zipfile")
+    generate_parser.add_argument("-c", "--config", nargs='?', default=None, help="Path to otter configuration file; ./otter_config.json automatically checked")
+    generate_parser.add_argument("-r", "--requirements", nargs='?', default=None, help="Path to requirements.txt file; ./requirements.txt automatically checked")
+    generate_parser.add_argument("--overwrite-requirements", default=False, action="store_true", help="Overwrite (rather than append to) default requirements for Gradescope; ignored if no REQUIREMENTS argument")
+    generate_parser.add_argument("-l", "--lang", default="python", choices=["python", "r"], type=str, help="Assignment programming language; defaults to Python")
+    generate_parser.add_argument("--autograder-dir", nargs="?", default="/autograder", help="Root autograding directory inside grading container")
+    generate_parser.add_argument("--username", default=None, help="Gradescope username for generating a token")
+    generate_parser.add_argument("--password", default=None, help="Gradescope password for generating a token")
+    generate_parser.add_argument("files", nargs='*', help="Other support files needed for grading (e.g. .py files, data files)")
 
-
-    ##### PARSER FOR otter generate autograder #####
-    generate_autograder_parser = generate_subparsers.add_parser("autograder", description="Create an autograder zip file for Gradescope")
-    generate_autograder_parser.add_argument("-t", "--tests-path", nargs='?', type=str, default="./tests/", help="Path to test files")
-    generate_autograder_parser.add_argument("-o", "--output-path", nargs='?', type=str, default="./", help="Path to which to write zipfile")
-    generate_autograder_parser.add_argument("-r", "--requirements", nargs='?', default=None, help="Path to requirements.txt file; ./requirements.txt automatically checked")
-    generate_autograder_parser.add_argument("--overwrite-requirements", default=False, action="store_true", help="Overwrite (rather than append to) default requirements for Gradescope; ignored if no REQUIREMENTS argument")
-    generate_autograder_parser.add_argument("-l", "--lang", default="python", type=str, help="Assignment programming language; defaults to Python")
-    generate_autograder_parser.add_argument("--threshold", type=float, default=None, help="Pass/fail score threshold")
-    generate_autograder_parser.add_argument("--points", type=float, default=None, help="Points possible, overrides sum of test points")
-    generate_autograder_parser.add_argument("--show-stdout", action="store_true", default=False, help="Show autograder test results (P/F only, no hints) after publishing grades (incl. hidden tests)")
-    generate_autograder_parser.add_argument("--show-hidden", action="store_true", default=False, help="Show autograder results for hidden tests after publishing grades")
-    generate_autograder_parser.add_argument("--seed", type=int, default=None, help="A random seed to be executed before each cell")
-    generate_autograder_parser.add_argument("--token", default="", nargs="?", help="Gradescope token for generating and uploading PDFs")
-    generate_autograder_parser.add_argument("--unfiltered-pdfs", default=False, action="store_true", help="Whether the PDFs should be unfiltered")
-    generate_autograder_parser.add_argument("--no-pagebreaks", default=False, action="store_true", help="Whether the PDFs should not have page breaks between questions")
-    generate_autograder_parser.add_argument("--course-id", default=None, help="Gradescope course ID")
-    generate_autograder_parser.add_argument("--assignment-id", default=None, help="Gradescope assignment ID for PDFs")
-    generate_autograder_parser.add_argument("--grade-from-log", default=False, action="store_true", help="Whether to grade assignments based on the logged environments")
-    generate_autograder_parser.add_argument("--serialized-variables", default="{}", help="String representation of Python dict mapping variable names to full types for verification when deserializing log")
-    generate_autograder_parser.add_argument("--public-multiplier", nargs="?", default=0, type=float, help="Percentage of points to award for passing all public tests")
-    generate_autograder_parser.add_argument("--autograder-dir", nargs="?", default="/autograder", help="Root autograding directory inside grading container")
-    generate_autograder_parser.add_argument("files", nargs='*', help="Other support files needed for grading (e.g. .py files, data files)")
-
-    generate_autograder_parser.set_defaults(func_str="generate.autograder.main")
-
-
-    ##### PARSER FOR otter generate token #####
-    generate_token_parser = generate_subparsers.add_parser("token", description="Get a Gradescope token")
-
-    generate_token_parser.set_defaults(func_str="generate.token.main")
+    generate_parser.set_defaults(func_str="generate.main")
 
 
     ##### PARSER FOR otter grade #####
@@ -127,8 +84,8 @@ def get_parser():
 
     # necessary path arguments
     grade_parser.add_argument("-p", "--path", type=str, default="./", help="Path to directory of submissions")
-    grade_parser.add_argument("-t", "--tests-path", type=str, default="./tests/", help="Path to directory of tests")
-    grade_parser.add_argument("-o", "--output-path", type=str, default="./", help="Path to which to write output")
+    grade_parser.add_argument("-a", "--autograder", type=str, default="./autograder.zip", help="Path to autograder zip file")
+    grade_parser.add_argument("-o", "--output-dir", type=str, default="./", help="Directory to which to write output")
 
     # metadata parser arguments
     grade_parser.add_argument("-g", "--gradescope", action="store_true", default=False, help="Flag for Gradescope export")
@@ -141,25 +98,32 @@ def get_parser():
     grade_parser.add_argument("-z", "--zips", action="store_true", default=False, help="Whether submissions are zip files from Notebook.export")
 
     # PDF export options
-    grade_parser.add_argument("--pdfs", default=False, const="unfiltered", choices=["unfiltered", "html"], nargs="?")
-    # grade_parser.add_argument("--pdf", action="store_true", default=False, help="Create unfiltered PDFs for manual grading")
-    # grade_parser.add_argument("--tag-filter", action="store_true", default=False, help="Create a tag-filtered PDF for manual grading")
-    # grade_parser.add_argument("--html-filter", action="store_true", default=False, help="Create an HTML comment-filtered PDF for manual grading")
+    grade_parser.add_argument("--pdfs", default=False, action="store_true", help="Whether to copy notebook PDFs out of containers")
 
     # other settings and optional arguments
-    grade_parser.add_argument("-f", "--files", nargs="+", help="Specify support files needed to execute code (e.g. utils, data files)")
     grade_parser.add_argument("-v", "--verbose", action="store_true", help="Flag for verbose output")
-    grade_parser.add_argument("--seed", type=int, default=None, help="A random seed to be executed before each cell")
-    grade_parser.add_argument("-r", "--requirements", default=None, type=str, help="Flag for Python requirements file path; ./requirements.txt automatically checked")
     grade_parser.add_argument("--containers", type=int, help="Specify number of containers to run in parallel")
     grade_parser.add_argument("--image", default="ucbdsinfra/otter-grader", help="Custom docker image to run on")
     grade_parser.add_argument("--no-kill", action="store_true", default=False, help="Do not kill containers after grading")
     grade_parser.add_argument("--debug", action="store_true", default=False, help="Print stdout/stderr from grading for debugging")
 
+    grade_parser.add_argument("--prune", action="store_true", default=False, help="Prune all of Otter's grading images")
+    grade_parser.add_argument("-f", "--force", action="store_true", default=False, help="Force action (don't ask for confirmation)")
+
     grade_parser.set_defaults(func_str="grade.main")
 
 
-    
+    ###### PARSER FOR otter run #####
+    run_parser = subparsers.add_parser("run", description="Run non-containerized Otter on a single submission") # TODO
+    run_parser.add_argument("submission", help="Path to submission to be graded")
+    run_parser.add_argument("-a", "--autograder", default="./autograder.zip", help="Path to autograder zip file")
+    run_parser.add_argument("-o", "--output-dir", default="./", help="Directory to which to write output")
+    run_parser.add_argument("--no-logo", action="store_true", default=False, help="Suppress Otter logo in stdout")
+    run_parser.add_argument("--debug", default=False, action="store_true", help="Do not ignore errors when running submission")
+
+    run_parser.set_defaults(func_str="run.main")
+
+
     ###### PARSER FOR otter service #####
     service_parser = subparsers.add_parser("service", description="Create and manage an otter-service")
     service_subparsers = service_parser.add_subparsers()
